@@ -36,3 +36,6 @@ SDK_INVALID_CREDENTIAL = 'SDK.InvalidCredential'
 SDK_INVALID_SESSION_EXPIRATION = 'SDK.InvalidSessionExpiration'
 SDK_GET_SESSION_CREDENTIAL_FAILED = 'SDK.GetSessionCredentialFailed'
 SDK_INVALID_PARAMS = 'SDK.InvalidParams'
+SDK_NOT_SUPPORT = 'SDK.NotSupport'
+SDK_ENDPOINT_RESOLVING_ERROR = 'SDK.EndpointResolvingError'
+SDK_ENDPOINT_TESTABILITY = 'SDK.EndpointTestability'
\ No newline at end of file
