@@ -106,6 +106,7 @@ class AcsRequest:
         self._location_service_code = location_service_code
         self._location_endpoint_type = location_endpoint_type
         self.add_header('x-sdk-invoke-type', 'normal')
+        self.endpoint = None
 
     def add_query_param(self, k, v):
         self._params[k] = v
@@ -170,6 +171,9 @@ class AcsRequest:
     def set_query_params(self, params):
         self._params = params
 
+    def set_body_params(self, body_params):
+        self._body_params = body_params
+
     def set_content(self, content):
         """
 
@@ -230,6 +234,9 @@ class AcsRequest:
     def get_signed_header(self, region_id, ak, secret):
         pass
 
+    def set_endpoint(self, endpoint):
+        self.endpoint = endpoint
+
 
 class RpcRequest(AcsRequest):
     """
@@ -380,8 +387,10 @@ class RoaRequest(AcsRequest):
         if self.get_content() is not None:
             md5_str = md5_tool.get_md5_base64_str(self.get_content())
             self.add_header('Content-MD5', md5_str)
-        # if 'RegionId' not in sign_params.keys():
-        #     sign_params['RegionId'] = region_id
+        if 'RegionId' not in sign_params.keys():
+            sign_params['RegionId'] = region_id
+            self.add_header('x-acs-region-id', region_id)
+
         signed_headers = roa_signer.get_signature_headers(
             sign_params,
             ak,
@@ -518,25 +527,38 @@ class OssRequest(AcsRequest):
         return url
 
 
-class CommonRequest(RpcRequest, RoaRequest):
-    def __init__(self, domain=None, version=None, action_name=None, uri_pattern=None, product=None):
-        RoaRequest.__init__(self, product, version, action_name)
-        RpcRequest.__init__(self, product, version, action_name)
+class CommonRequest(AcsRequest):
+    def __init__(self, domain=None, version=None, action_name=None, uri_pattern=None, product=None, location_endpoint_type='openAPI'):
+        super(CommonRequest, self).__init__(product)
 
-        self._domain = domain
+        self.request = None
+        self.endpoint = domain
         self._version = version
         self._action_name = action_name
         self._uri_pattern = uri_pattern
         self._product = product
-        self._location_endpoint_type = 'openAPI',
+        self._location_endpoint_type = location_endpoint_type,
         self._signer = sha_hmac1
         self.add_header('x-sdk-invoke-type', 'common')
+        self._path_params = None
+        self._method = "GET"
+
+    def get_path_params(self):
+        return self._path_params
+
+    def set_path_params(self, path_params):
+        self._path_params = path_params
+
+    def add_path_param(self, k, v):
+        if self._path_params is None:
+            self._path_params = {}
+        self._path_params[k] = v
 
     def set_domain(self, domain):
-        self._domain = domain
+        self.endpoint = domain
 
     def get_domain(self):
-        return self._domain
+        return self.endpoint
 
     def set_version(self, version):
         self._version = version
@@ -569,26 +591,60 @@ class CommonRequest(RpcRequest, RoaRequest):
         if not self._action_name and not self._uri_pattern:
             raise exceptions.ClientException(error_code.SDK_INVALID_PARAMS,
                                              'At least one of [action] and [uri_pattern] has a value')
-        if not self._domain and not self._product:
+        if not self.endpoint and not self._product:
             raise exceptions.ClientException(error_code.SDK_INVALID_PARAMS,
                                              'At least one of [domain] and [product_name] has a value')
 
         if self._uri_pattern:
             self._style = STYLE_ROA
+            self.request = RoaRequest(product=self.get_product(), version=self.get_version(),
+                                      action_name=self.get_action_name(),
+                                      location_endpoint_type=self.get_location_endpoint_type()
+                                      )
+            self.fill_params()
         else:
             self._style = STYLE_RPC
+            self.request = RpcRequest(product=self.get_product(), version=self.get_version(),
+                                      action_name=self.get_action_name(),
+                                      location_endpoint_type=self.get_location_endpoint_type(),
+                                      )
+            self.fill_params()
+
 
     def get_style(self):
         return self._style
 
     def get_url(self, region_id, ak, secret):
-        if self._style == STYLE_RPC:
-            return RpcRequest.get_url(self, region_id, ak, secret)
-        else:
-            return RoaRequest.get_url(self, region_id, ak, secret)
+        return self.request.get_url(region_id, ak, secret)
 
     def get_signed_header(self, region_id, ak, secret):
-        if self._style == STYLE_RPC:
-            return RpcRequest.get_signed_header(self, region_id, ak, secret)
-        else:
-            return RoaRequest.get_signed_header(self, region_id, ak, secret)
+        return self.request.get_signed_header(region_id, ak, secret)
+
+    def fill_params(self):
+
+        self.request.set_uri_pattern(self.get_uri_pattern())
+
+        self.request.set_uri_params(self.get_uri_params())
+
+        self.request.set_method(self.get_method())
+
+        self.request.set_product(self.get_product())
+
+        self.request.set_version(self.get_version())
+
+        self.request.set_action_name(self.get_action_name())
+
+        self.request.set_accept_format(self.get_accept_format())
+
+        self.request.set_protocol_type(self.get_protocol_type())
+
+        self.request.set_query_params(self.get_query_params())
+
+        self.request.set_content(self.get_content())
+
+        self.request.set_headers(self.get_headers())
+
+        self.request.set_location_service_code(self.get_location_service_code())
+
+        self.request.set_body_params(self.get_body_params())
+
